/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

import QtQuick 1.1
import com.nokia.meego 1.1
import EmuMaster 1.0

Page {
	id: displayRectSelector

	ScreenDimensionsHelper { id: dmHelper }

	property int screenWidth: dmHelper.width
	property int screenHeight: dmHelper.height
	property bool localSettings: true

	property int displayX: 0
	property int displayY: 0
	property int displayWidth: screenWidth
	property int displayHeight: screenHeight
	property color simColor: "gray"

	tools: ToolBarLayout {
		ToolIcon {
			iconId: "toolbar-back"
			onClicked: {
				var rect = Qt.rect(displayX, displayY,
								   displayWidth, displayHeight)
				if (localSettings)
					emuView.dmHelper.preferredDstRect = rect
				else
					diskGallery.setGlobalOption("preferredDstRect", rect)
				pageStack.pop()
			}
		}
	}

	Item {
		id: screenItem
		width: appWindow.inPortrait ? parent.width : parent.height
		height: appWindow.inPortrait ? (screenBox.height + 32) : width

		Rectangle {
			id: screenBox
			color: "transparent"
			border.color: simColor
			border.width: 1
			width: parent.width - 32
			height: width * screenHeight / screenWidth
			anchors.centerIn: parent

			Rectangle {
				x: displayX * screenBox.width / screenWidth
				y: displayY * screenBox.height / screenHeight
				width: displayWidth * screenBox.width / screenWidth
				height: displayHeight * screenBox.height / screenHeight
				color: "transparent"
				border.color: simColor
				border.width: 2

				Text {
					color: simColor
					anchors.bottom: parent.bottom
					anchors.bottomMargin: 5
					anchors.horizontalCenter: parent.horizontalCenter
					font.pixelSize: 16
					text: displayWidth + " px"
				}

				Text {
					color: simColor
					anchors.right: parent.right
					anchors.rightMargin: 5
					anchors.verticalCenter: parent.verticalCenter
					font.pixelSize: 16
					text: displayHeight + " px"
				}
			}
		}
	}

	Flickable {
		id: flickable
		anchors.top: appWindow.inPortrait ? screenItem.bottom : parent.top
		anchors.bottom: parent.bottom
		anchors.left: appWindow.inPortrait ? parent.left : screenItem.right
		anchors.right: parent.right
		clip: true
		boundsBehavior: ListView.StopAtBounds

		contentWidth: column.width
		contentHeight: column.height+10

		Column {
			id: column
			width: flickable.width

			SectionSeperator { text: qsTr("RECT") }

			Label { text: qsTr("Horizontal Position"); x: 8 }
			Slider {
				id: hposSlider
				width: parent.width
				minimumValue: 0
				maximumValue: screenWidth - displayWidth
				stepSize: 1
				valueIndicatorVisible: true
				onValueChanged: displayX = value
				Component.onCompleted: value = displayX
			}
			Label { text: qsTr("Vertical Position"); x: 8 }
			Slider {
				id: vposSlider
				width: parent.width
				minimumValue: 0
				maximumValue: screenHeight - displayHeight
				stepSize: 1
				valueIndicatorVisible: true
				onValueChanged: displayY = value
				Component.onCompleted: value = displayY
			}
			Label { text: qsTr("Width"); x: 8 }
			Slider {
				width: parent.width
				maximumValue: screenWidth
				stepSize: 2
				valueIndicatorVisible: true
				onValueChanged: displayRectSelector.displayWidth = value
				Component.onCompleted: {
					value = displayWidth
					minimumValue = 200
				}
			}
			Label { text: qsTr("Height"); x: 8 }
			Slider {
				width: parent.width
				maximumValue: screenHeight
				stepSize: 2
				valueIndicatorVisible: true
				onValueChanged: displayRectSelector.displayHeight = value
				Component.onCompleted: {
					value = displayHeight
					minimumValue = 200
				}
			}

			SectionSeperator { text: qsTr("ALIGN") }
			Item { width: 1; height: 16 }

			ButtonRow {
				exclusive: false
				anchors.horizontalCenter: parent.horizontalCenter
				width: parent.width-32

				Button {
					iconSource: "../img/align_left.png"
					onClicked: hposSlider.value = 0
				}
				Button {
					iconSource: "../img/align_h_center.png"
					onClicked: hposSlider.value = screenWidth/2 - displayWidth/2
				}
				Button {
					iconSource: "../img/align_right.png"
					onClicked: hposSlider.value = screenWidth - displayWidth
				}
			}

			Item { width: 1; height: 16 }

			ButtonRow {
				exclusive: false
				anchors.horizontalCenter: parent.horizontalCenter
				width: parent.width-32

				Button {
					iconSource: "../img/align_top.png"
					onClicked: vposSlider.value = 0
				}
				Button {
					iconSource: "../img/align_v_center.png"
					onClicked: vposSlider.value = screenHeight/2 - displayHeight/2
				}
				Button {
					iconSource: "../img/align_bottom.png"
					onClicked: vposSlider.value = screenHeight - displayHeight
				}
			}
		}
	}
	ScrollDecorator { flickableItem: flickable }

	Component.onCompleted: {
		var rect
		if (localSettings)
			rect = emuView.dmHelper.preferredDstRect
		else
			rect = diskGallery.globalOption("preferredDstRect")
		displayX = rect.x
		displayY = rect.y
		displayWidth = rect.width
		displayHeight = rect.height
	}
}
