/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

import QtQuick 1.1
import com.nokia.meego 1.1
import EmuMaster 1.0

SettingsPage {
	inputContent: [
		SelectionItem {
			titleText: qsTr("PSX Input Port A")
			subtitleText: emu.input.devices[0].type
			onClicked: inputDeviceTypeSelector.setDeviceNumAndOpen(0)
		},
		SelectionItem {
			titleText: qsTr("PSX Input Port B")
			subtitleText: emu.input.devices[1].type
			onClicked: inputDeviceTypeSelector.setDeviceNumAndOpen(1)
		}
	]
	videoContent: [
		EMSwitchOption {
			id: gpuFrameSkipSwitch
			text: qsTr("GPU Frameskip")
			function refresh() { checked = emu.gpuFrameSkip }
			Component.onCompleted: refresh()
			onCheckedChanged: emu.gpuFrameSkip = checked
			Connections { target: emu; onGpuFrameSkipChanged: gpuFrameSkipSwitch.refresh() }
		}
	]
	miscContent: [
		ButtonRow {
			visible: emu.diskCount > 1
			spacing: 5

			Repeater {
				model: emu.diskCount
				Button {
					text: "CD" + (index+1)
					checked: emu.diskIndex === index
					onClicked: emu.diskIndex = index
				}
			}
		},
		EMSwitchOption {
			text: qsTr("CD-XA Playback")
			onCheckedChanged: emu.cdxaEnable = checked
			Component.onCompleted: checked = emu.cdxaEnable
		},
		EMSwitchOption {
			text: qsTr("CD-DA Playback")
			onCheckedChanged: emu.cddaEnable = checked
			Component.onCompleted: checked = emu.cddaEnable
		},
		Label {
			anchors.left: parent.left
			anchors.leftMargin: 8
			anchors.right: parent.right
			anchors.rightMargin: 16
			text: qsTr("Disk Label: ") + emu.diskLabel
		}
	]

	SelectionDialog {
		id: inputDeviceTypeSelector
		property int deviceNum
		model: StringListProxy {
			id: inputDeviceTypeModel
			stringListModel: emu.input.availableTypes
		}
		onAccepted: emu.input.setDeviceType(deviceNum, inputDeviceTypeModel.get(selectedIndex))

		function setDeviceNumAndOpen(num) {
			deviceNum = num
			selectedIndex = inputDeviceTypeModel.indexOf(emu.input.devices[num].type)
			open()
		}
	}
}
