/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

import QtQuick 1.1
import com.nokia.meego 1.1

Dialog {
	id: root
	anchors.fill: parent
	anchors.topMargin: 16
	anchors.bottomMargin: 16

	property variant inputDevice
	property string selectedProfile: "None"

	content: GridView {
		id: view
		width: root.width
		height: root.height
		model: inputDevice.profiles
		cellWidth: appWindow.inPortrait ? root.width : (root.width/2)
		cellHeight: 240
		flow: GridView.LeftToRight

		delegate: Item {
			width: view.cellWidth
			height: view.cellHeight

			BorderImage {
				id: background
				anchors.fill: parent
				anchors.margins: 4
				visible: mouseArea.pressed || (root.selectedProfile == modelData)
				source: theme.inverted ? "image://theme/meegotouch-panel-inverted-background-pressed" : "image://theme/meegotouch-panel-background-pressed"
			}

			Image {
				id: img
				width: 320
				height: 180
				y: 8
				anchors.horizontalCenter: parent.horizontalCenter
				source: "image://virtualpad/" + modelData
				smooth: true

				Rectangle {
					anchors.fill: parent
					color: "transparent"
					border.color: "gray"
					border.width: 1
				}
			}

			Label {
				anchors.horizontalCenter: img.horizontalCenter
				anchors.top: img.bottom
				anchors.topMargin: 8
				text: modelData
			}

			MouseArea {
				id: mouseArea
				anchors.fill: parent
				onClicked: {
					root.selectedProfile = modelData
					root.accept()
				}
			}
		}
		ScrollDecorator { flickableItem: view }
	}
}
