/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

import QtQuick 1.1
import EmuMaster 1.0
import com.nokia.meego 1.1
import com.nokia.extras 1.1

Page {
	id: collectionMenuPage
	BiosChecker { id: biosChecker }

	Flickable {
		id: flickable
		anchors.fill: parent
		contentWidth: width
		contentHeight: collectionGrid.height+(appWindow.inPortrait?0:64)
		visible: !diskGallery.massStorageInUse

		Grid {
			id: collectionGrid
			rows: appWindow.inPortrait ? 5 : 4
			columns: appWindow.inPortrait ? 2 : 3
			anchors.horizontalCenter: parent.horizontalCenter

			CollectionTypeButton { name: "fav"; nameForced: true }
			CollectionTypeButton { name: "nes" }
			CollectionTypeButton { name: "snes" }
			CollectionTypeButton {
				name: "gba"
				function otherAction() {
					if (!biosChecker.testGbaBios(diskGallery.gbaBiosFilePath)) {
						errorDialog.message = qsTr("BIOS missing or not properly configured!")
						errorDialog.open()
					} else {
						selectCollection("gba")
					}
					return true
				}
			}
			CollectionTypeButton {
				name: "psx"
				function otherAction() {
					if (!biosChecker.testPsxBios(diskGallery.psxBiosFilePath)) {
						errorDialog.message = qsTr("BIOS missing or not properly configured!")
						errorDialog.open()
					} else {
						selectCollection("psx")
					}
					return true
				}
			}
			CollectionTypeButton { name: "amiga" }
			CollectionTypeButton { name: "pico" }
			CollectionTypeButton {
				name: "conf"
				nameForced: true
				function otherAction() {
					pageStack.push(Qt.resolvedUrl("GlobalSettings.qml"))
					return true
				}
			}
			CollectionTypeButton {
				name: "6axis"
				nameForced: true
				function otherAction() {
					pageStack.push(Qt.resolvedUrl("SixAxisMonitor.qml"))
					return true
				}

				CountBubble {
					anchors.top: parent.top
					anchors.right: parent.right
					anchors.topMargin: 16
					anchors.rightMargin: 16

					largeSized: true
					value: sixAxisMonitor.addresses.length
					visible: value !== 0
				}
			}
			CollectionTypeButton {
				name: "help"
				nameForced: true
				function otherAction() {
					pageStack.push(Qt.resolvedUrl("AboutPage.qml"))// TODO: "UserGuide.qml"))
					return true
				}
			}
		}

	}
	ScrollDecorator { flickableItem: flickable }

	Connections {
		target: diskGallery
		onMassStorageInUseChanged: {
			if (diskGallery.massStorageInUse) {
				while (pageStack.depth > 1)
					pageStack.pop()
			}
		}
	}

	MassStorageWarning {}
}
