/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

import QtQuick 1.1
import com.nokia.meego 1.1
import "../base"

Page {
	id: diskLaunchPage
	property bool addRemoveIconToggle: false
	property bool addRemoveFavToggle: false
	property alias coverSource: coverItem.coverSource
	property int diskIndex
	default property alias columnContent: menuColumn.children

	tools: ToolBarLayout {
		ToolIcon {
			iconId: "toolbar-back"
			onClicked: pageStack.pop()
		}
	}

	children: [

	CoverItem {
		id: coverItem
		onClicked: {
			var advOptions = []
			if (diskLaunchPage.commitOptions)
				advOptions = diskLaunchPage.commitOptions()

			var confStr = ""

			for (var item in advOptions) {
				if (advOptions.hasOwnProperty(item)) {
					if (confStr != "")
						confStr += ","
					confStr += item + "=" + advOptions[item]
				}
			}

			diskGallery.advancedLaunch(diskIndex, autoSaveLoadEnabled.checked, confStr)
		}
	},

	Flickable {
		id: flickable
		anchors.top: appWindow.inPortrait ? coverItem.bottom : parent.top
		anchors.bottom: parent.bottom
		anchors.left: appWindow.inPortrait ? parent.left : coverItem.right
		anchors.right: parent.right
		clip: true

		contentWidth: menuColumn.width
		contentHeight: menuColumn.height+10

		Column {
			id: menuColumn
			width: flickable.width

			PageSelectionItem {
				titleText: qsTr("Select Cover")
				onClicked: pageStack.push(Qt.resolvedUrl("CoverSelectorPage.qml"),
										  { diskIndex: diskLaunchPage.diskIndex })
			}
			SelectionItem {
				titleText: qsTr("Add to Favourites")
				iconSource: "image://theme/icon-m-toolbar-favorite-unmark-white"
				visible: !addRemoveFavToggle
				onClicked: {
					diskListModel.addToFav(diskIndex)
					addRemoveFavToggle = true
				}
			}
			SelectionItem {
				titleText: qsTr("Remove from Favourites")
				iconSource: "image://theme/icon-m-toolbar-favorite-mark-white"
				visible: addRemoveFavToggle
				onClicked: {
					diskListModel.removeFromFav(diskIndex)
					addRemoveFavToggle = false
				}
			}
			PageSelectionItem {
				titleText: qsTr("Create Icon in Home Screen")
				visible: !addRemoveIconToggle
				onClicked: homeScreenIcon(diskIndex)
			}
			SelectionItem {
				titleText: qsTr("Remove Icon from Home Screen")
				iconSource: "image://theme/icon-m-toolbar-cancle-white"
				visible: addRemoveIconToggle
				onClicked: {
					diskListModel.removeIconFromHomeScreen(diskIndex)
					addRemoveIconToggle = false
				}
			}
			SelectionItem {
				titleText: qsTr("Delete")
				iconSource: "image://theme/icon-m-toolbar-delete-white"
				onClicked: removeDiskDialog.prepareAndOpen()
			}

			SectionSeperator { text: qsTr("ADVANCED OPTIONS") }

			EMSwitchOption {
				id: autoSaveLoadEnabled
				text: qsTr("Auto Save/Load")
				checked: diskGallery.globalOption("autoSaveLoadEnable")
			}
		}
	},
	ScrollDecorator { flickableItem: flickable },

	QueryDialog {
		id: removeDiskDialog
		acceptButtonText: qsTr("Yes")
		rejectButtonText: qsTr("No")
		titleText: qsTr("Delete")
		onAccepted: {
			diskListModel.trash(diskIndex)
			pageStack.pop()
		}

		function prepareAndOpen() {
			removeDiskDialog.message = qsTr("Do you really want to delete\n\"%1\" ?")
											.arg(diskListModel.getDiskTitle(diskIndex))
			removeDiskDialog.open()
		}
	}

	]

	Connections {
		target: pageStack
		onCurrentPageChanged: updateLinks()
	}

	onDiskIndexChanged: updateLinks()

	function updateLinks() {
		addRemoveIconToggle = diskListModel.iconInHomeScreenExists(diskIndex)
		addRemoveFavToggle = diskListModel.diskInFavExists(diskIndex)
	}

	function homeScreenIcon() {
		if (diskListModel.getScreenShotUpdate(diskIndex) < 0) {
			errorDialog.message = qsTr("You need to make a screenshot first!")
			errorDialog.open()
		} else {
			var path = qsTr("image://disk/%1/%2*%3")
							.arg(diskListModel.getDiskEmuName(diskIndex))
							.arg(diskListModel.getDiskTitle(diskIndex))
							.arg(diskListModel.getScreenShotUpdate(diskIndex))
			pageStack.push(Qt.resolvedUrl("HomeScreenIconSheet.qml"),
						   { imgSource: path, diskIndex: diskIndex })
		}
	}
}
