/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

import QtQuick 1.1
import com.nokia.meego 1.1
import "../base"

Page {
	id: galleryPage

	ListModel { id: nullModel }

	function updateModel() {
		diskViewPortrait.model = nullModel
		diskViewPortrait.model = diskListModel
		diskViewLandscape.model = nullModel
		diskViewLandscape.model = diskListModel
	}

	function diskClickHandle(index, imageSource) {
		if (searchBar.visible) {
			searchBar.visible = false
		} else {
			var emuName = diskListModel.getDiskEmuName(index)
			var qmlPage = emuName.charAt(0).toUpperCase() +
					emuName.substr(1) + "DiskLaunchPage.qml"
			pageStack.push(Qt.resolvedUrl(qmlPage),
						   { coverSource: imageSource,
							   diskIndex: index })
		}
	}

	ListView {
		id: diskViewPortrait
		anchors.fill: parent
		spacing: 10
		clip: true
		visible: appWindow.inPortrait

		delegate: ImageListViewDelegate {
			width: 480
			height: 280
			text: title
			imgSource: imageSource
			onClicked: galleryPage.diskClickHandle(index, imageSource)
		}
		section.property: "alphabet"
		section.criteria: ViewSection.FullString
		section.delegate: SectionSeperator { text: section; rightPad: 80 }

		function customSectionScrollerDataHandler() {
			var sectionData = []
			var _sections = []
			var current = "", item;
			for (var i = 0, count = model.count; i < count; i++) {
				item = model.getAlphabet(i);
				if (item !== current) {
					current = item;
					_sections.push(current);
					sectionData.push({ index: i, header: current });
				}
			}
			return { sectionData: sectionData, _sections: _sections }
		}
	}
	MySectionScroller { listView: diskViewPortrait }
	ScrollDecorator {
		flickableItem: diskViewPortrait
		__minIndicatorSize: 80
	}

	GridView {
		id: diskViewLandscape
		anchors.fill: parent
		visible: !appWindow.inPortrait
		cellWidth: 284
		cellHeight: 240

		delegate: ImageListViewDelegate {
			width: 270
			height: 220
			text: titleElided
			imgSource: imageSource
			onClicked: galleryPage.diskClickHandle(index, imageSource)
		}
	}
	ScrollDecorator {
		flickableItem: diskViewLandscape
		__minIndicatorSize: 80
	}

	ToolBar {
		id: searchBar
		anchors.top: parent.top
		visible: false

		tools: ToolBarLayout {
			TextField {
				id: searchField
				anchors.verticalCenter: parent.verticalCenter
				placeholderText: qsTr("Search")
				inputMethodHints: Qt.ImhNoPredictiveText|Qt.ImhNoAutoUppercase

				onTextChanged: {
					if (visible)
						diskListModel.setNameFilter(searchField.text)
				}
				Image {
					source: "image://theme/icon-s-cancel"
					anchors {
						right: parent.right; rightMargin: 10
						verticalCenter: parent.verticalCenter
					}
				}
				MouseArea {
					width: 80
					height: parent.height
					anchors.right: parent.right
					onClicked: searchBar.visible = false
				}
			}
		}

		function hideAndClear() {
			searchBar.visible = false
			searchField.text = ""
		}
	}

	tools: ToolBarLayout {
		ToolIcon {
			iconId: "toolbar-back"
			onClicked: {
				searchBar.hideAndClear()
				pageStack.pop()
			}
		}

		ToolIcon {
			iconId: "icon-m-common-search-inverse"
			onClicked: {
				searchBar.visible = !searchBar.visible
				searchField.focus = visible
			}
		}
	}
}
