/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

import QtQuick 1.1
import com.nokia.meego 1.1

Page {
	id: saveIconPage

	property int diskIndex

	property alias imgSource: img.source
	property alias imgScale: imageScaler.value

	tools: ToolBarLayout {
		ToolIcon {
			iconId: "toolbar-back"
			onClicked: pageStack.pop()
		}
		ToolIcon {
			property bool selectionReady: useWholeImgCheckBox.checked || selectionRect.visible

			iconId: "toolbar-done"
			onClicked: {
				if (selectionReady) {
					diskListModel.addIconToHomeScreen(
								saveIconPage.diskIndex,
								imageScaler.value,
								selectionRect.x, selectionRect.y,
								harmattanStyleChecker.checked,
								useWholeImgCheckBox.checked)
					pageStack.pop()
				}
			}
			visible: selectionReady
		}
	}

	Item {
		width: parent.width
		height: 400
		anchors.centerIn: parent
		visible: !useWholeImgCheckBox.checked

		Image {
			id: img
			anchors.centerIn: parent
			scale: imageScaler.value
		}

		Item {
			x: img.x - (img.scale-1)*img.width/2
			y: img.y - (img.scale-1)*img.height/2
			width: img.width*img.scale
			height: img.height*img.scale

			Rectangle {
				id: selectionRect
				width: 80
				height: 80
				color: Qt.rgba(1, 1, 1, 0.3)
				border.color: "white"
				border.width: 2
				visible: false
			}

			MouseArea {
				anchors.fill: parent
				drag.target: selectionRect
				drag.axis: Drag.XandYAxis
				drag.minimumX: 0
				drag.maximumX: width - selectionRect.width
				drag.minimumY: 0
				drag.maximumY: height - selectionRect.height
				onPressed: {
					if (mouse.x >= 40 && mouse.y >= 40 && mouse.x+40 < width && mouse.y+40 < height) {
						selectionRect.x = mouse.x - 40
						selectionRect.y = mouse.y - 40
						selectionRect.visible = true
					}
				}
			}
		}
	}

	Column {
		spacing: 8
		ButtonColumn {
			spacing: 8
			RadioButton { id: harmattanStyleChecker; text: qsTr("Harmattan Style") }
			RadioButton { text: qsTr("Plain Style") }
		}

		CheckBox {
			id : useWholeImgCheckBox
			text: qsTr("Use Whole Image")
			checked: false
		}
	}

	Slider {
		id: imageScaler;
		visible: !useWholeImgCheckBox.checked
		anchors.bottom: parent.bottom
		width: parent.width
		orientation: Qt.Horizontal
		minimumValue: 0.1; maximumValue: 2.0
		value: 1.0
		onValueChanged: selectionRect.visible = false
	}
	orientationLock: PageOrientation.LockPortrait
}
