/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

import QtQuick 1.1
import com.nokia.meego 1.1
import "../base"

DiskLaunchPage {
	id: root

	SelectionItem {
		titleText: qsTr("TV Encoding System")
		subtitleText: tvSystemDialog.selectedSystem()
		onClicked: tvSystemDialog.open()
	}

	SelectionItem {
		titleText: qsTr("Render Method")
		subtitleText: renderMethodDialog.selectedMethod()
		onClicked: renderMethodDialog.open()
	}

	SelectionItem {
		titleText: qsTr("Extra Input")
		subtitleText: extraInputDialog.selectedExtIn()
		onClicked: extraInputDialog.open()
	}

	SelectionItem {
		titleText: qsTr("Cpu Type")
		subtitleText: cpuTypeDialog.selectedCpuType()
		onClicked: cpuTypeDialog.open()
	}

	children: [
		SelectionDialog {
			id: renderMethodDialog
			model: ListModel {
				id: renderMethodModel
				ListElement { name: "Auto" }
				ListElement { name: "Post All Render" }
				ListElement { name: "Pre All Render" }
				ListElement { name: "Post Render" }
				ListElement { name: "Pre Render" }
				ListElement { name: "Tile Render" }
			}
			titleText: qsTr("Select Render Method")
			selectedIndex: 0
			function selectedMethod() { return renderMethodModel.get(renderMethodDialog.selectedIndex).name }
		},
		SelectionDialog {
			id: tvSystemDialog
			model: ListModel {
				id: tvSystemModel
				ListElement { name: "Auto" }
				ListElement { name: "NTSC" }
				ListElement { name: "PAL" }
			}
			titleText: qsTr("Select TV Encoding System")
			selectedIndex: 0
			function selectedSystem() { return tvSystemModel.get(tvSystemDialog.selectedIndex).name }
		},
		SelectionDialog {
			id: extraInputDialog
			model: ListModel {
				id: extraInputModel
				ListElement { name: "Auto" }
				ListElement { name: "Zapper" }
				ListElement { name: "Paddle" }
			}
			titleText: qsTr("Select Extra Input")
			selectedIndex: 0
			function selectedExtIn() { return extraInputModel.get(extraInputDialog.selectedIndex).name }
		},
		SelectionDialog {
			id: cpuTypeDialog
			model: ListModel {
				id: cpuTypeModel
				ListElement { name: "Auto" }
				ListElement { name: "Recompiler" }
				ListElement { name: "Interpreter" }
			}
			titleText: qsTr("Select Cpu Type")
			selectedIndex: 0
			function selectedCpuType() { return cpuTypeModel.get(cpuTypeDialog.selectedIndex).name }
		}
	]
	function commitOptions() {
		var advOptions = []
		if (renderMethodDialog.selectedMethod() !== "Auto")
			advOptions["nes.renderMethod"] = renderMethodDialog.selectedIndex-1 // TODO: selectedMethod()
		if (tvSystemDialog.selectedSystem() !== "Auto")
			advOptions["nes.tvSystem"] = tvSystemDialog.selectedSystem()
		if (extraInputDialog.selectedExtIn() !== "Auto")
			advOptions["nes.extraInput"] = extraInputDialog.selectedIndex // TODO: selectedExtIn()
		if (cpuTypeDialog.selectedCpuType() !== "Auto")
			advOptions["nes.cpuType"] = cpuTypeDialog.selectedCpuType()
		return advOptions
	}
}
