/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

import QtQuick 1.1
import com.nokia.meego 1.1
import EmuMaster 1.0
import "../base"

DiskLaunchPage {
	id: root

	SelectionItem {
		titleText: qsTr("TV Encoding System")
		subtitleText: tvSystemDialog.selectedSystem()
		onClicked: tvSystemDialog.open()
	}
	SelectionItem {
		titleText: qsTr("BIOS")
		subtitleText: biosDialog.selectedBios()
		onClicked: biosDialog.open()
	}
	EMSwitchOption {
		id: skipBiosLogoSwitch
		text: qsTr("Skip BIOS Logo")
		checked: true
	}

	children: [
		SelectionDialog {
			id: tvSystemDialog
			titleText: qsTr("Select TV Encoding System")
			selectedIndex: 0
			model: ListModel {
				id: tvSystemModel
				ListElement { name: "Auto" }
				ListElement { name: "NTSC" }
				ListElement { name: "PAL" }
			}
			function selectedSystem() { return tvSystemModel.get(tvSystemDialog.selectedIndex).name }
		},
		SelectionDialog {
			id: biosDialog
			property string psxBiosOption: "psx.bios"
			titleText: qsTr("Select BIOS")
			model: StringListProxy {
				id: biosModel
				stringListModel: diskListModel.psxBioses
			}
			function selectedBios() { return (selectedIndex>=0) ? biosModel.get(biosDialog.selectedIndex) : "<Invalid>" }
			Component.onCompleted: selectedIndex = biosModel.indexOf(diskGallery.globalOption(psxBiosOption))
		}
	]
	function commitOptions() {
		var advOptions = []
		if (!skipBiosLogoSwitch.checked)
			advOptions["psx.skipBiosLogo"] = "off"
		if (tvSystemDialog.selectedSystem() !== "Auto")
			advOptions["psx.tvSystem"] = tvSystemDialog.selectedSystem()
		advOptions[biosDialog.psxBiosOption] = biosDialog.selectedBios()
		return advOptions
	}
}
