/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

import QtQuick 1.1
import com.nokia.meego 1.1
import "../base"

Page {
	tools: ToolBarLayout {
		ToolIcon {
			iconId: "toolbar-back"
			onClicked: pageStack.pop()
		}
	}

	Column {
		id: column
		width: parent.width
		spacing: 8

		Label {
			anchors.horizontalCenter: parent.horizontalCenter
			text: sixAxisMonitor.running ? qsTr("Monitor Running") : qsTr("Enter password for devel-su:")
		}

		TextField {
			id: develsuPasswordEdit
			width: parent.width-40
			anchors.horizontalCenter: parent.horizontalCenter
			echoMode: TextInput.Password
			visible: !sixAxisMonitor.running
		}

		Button {
			id: startButton
			anchors.horizontalCenter: parent.horizontalCenter
			text: qsTr("Start Monitor")
			visible: !sixAxisMonitor.running && !sixAxisMonitor.initializing &&
					 develsuPasswordEdit.text.length !== 0
			onClicked: sixAxisMonitor.start(develsuPasswordEdit.text)
		}

		BusyIndicator {
			anchors.horizontalCenter: parent.horizontalCenter
			platformStyle: BusyIndicatorStyle { size: "large" }
			running: sixAxisMonitor.initializing
			visible: sixAxisMonitor.initializing
		}
	}

	ListView {
		id: sixAxisListView
		width: parent.width
		anchors {
			top: column.bottom
			topMargin: 10
			bottom: parent.bottom
		}
		spacing: 10
		clip: true
		model: sixAxisMonitor.addresses
		delegate: Column {
			anchors.horizontalCenter: parent.horizontalCenter
			width: childrenRect.width
			spacing: 4
			Label {
				text: qsTr("%1. Bluetooth address: %2")
							.arg(index+1)
							.arg(modelData)
			}
			ButtonRow {
				exclusive: false
				Button {
					text: qsTr("Identify")
					onClicked: sixAxisMonitor.identify(index)
				}
				Button {
					text: qsTr("Disconnect")
					onClicked: sixAxisMonitor.disconnectDev(index)
				}
			}
		}
	}

	QueryDialog {
		id: errDialog
		rejectButtonText: qsTr("Close")
		titleText: qsTr("Error")
	}

	Connections {
		target: sixAxisMonitor
		onError: {
			errDialog.message = msg
			errDialog.open()
		}
	}
}
