/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

import QtQuick 1.1
import com.nokia.meego 1.1
import "../base"
import EmuMaster 1.0

Page {
	tools: ToolBarLayout {
		ToolIcon {
			iconId: "toolbar-back"
			onClicked: pageStack.pop()
		}
	}

	Flickable {
		id: flickable
		anchors.fill: parent
		width: parent.width
		flickableDirection: Flickable.VerticalFlick
		clip: true
		contentHeight: items.height+10

		Column {
			id: items
			width: parent.width
			height: childrenRect.height
			spacing: 20

			Label { text: qsTr("Pad Opacity"); x: 8 }
			Slider {
				id: opacitySlider
				width: parent.width
				minimumValue: 0.0
				maximumValue: 1.0
				stepSize: 0.05
				valueIndicatorVisible: true
				onValueChanged: diskGallery.setGlobalOption("padOpacity", value)
				Component.onCompleted: value = diskGallery.globalOption("padOpacity")
			}

			GlobalSettingsSwitchItem { text: qsTr("Haptic Feedback Enabled"); optionName: "hapticFeedbackEnable" }
			GlobalSettingsSwitchItem { text: qsTr("Show Images"); optionName: "padImageVisible" }
			GlobalSettingsSwitchItem { text: qsTr("Show Grid");	optionName: "gridVisible" }

			Item {
				width: parent.width
				Label {
					id: gridColorLabel
					text: qsTr("Grid Color")
					x: 8
					anchors.verticalCenter: parent.verticalCenter
				}
				Button {
					id: gridColorButton
					width: 80
					anchors.right: parent.right
					anchors.rightMargin: 16
					onClicked: colorDialog.open()
					anchors.verticalCenter: parent.verticalCenter

					Rectangle {
						id: gridColorView
						width: 40
						height: 40
						anchors.centerIn: parent
						function refresh() { gridColorView.color = diskGallery.globalOption("gridColor") }
						Component.onCompleted: refresh()
					}
				}
				Component.onCompleted: height = Math.max(gridColorLabel.height, gridColorButton.height)
			}

			Repeater {
				model: diskGallery.emus
				SelectionItem {
					id: profileSelectionProfile
					titleText: qsTr("Profile for %1").arg(modelData.toUpperCase())
					subtitleText: diskGallery.globalOption("input.touch0.profile-"+modelData)
					onClicked: {
						profileSelector.selectedProfile = subtitleText
						profileSelector.emuName = modelData
						profileSelector.selItem = profileSelectionProfile
						profileSelector.open()
					}
				}
			}
		}
	}

	ScrollDecorator { flickableItem: flickable }

	ColorDialog {
		id: colorDialog
		onAccepted: {
			diskGallery.setGlobalOption("gridColor", colorValue)
			gridColorView.refresh()
		}
	}

	TouchProfileSelectionDialog {
		id: profileSelector
		property SelectionItem selItem
		property string emuName
		inputDevice: touchInputDevice
		onAccepted: {
			diskGallery.setGlobalOption("input.touch0.profile-"+emuName, selectedProfile)
			selItem.subtitleText = selectedProfile
		}
	}
}
